@@ -1,4 +1,4 @@
-__all__=["B1io","utils","B1macros","utils2d","guitools","fitting","xanes","asamacros","asaxseval","unstable","distdist","saxssim"]
+__all__=["B1io","utils","B1macros","utils2d","guitools","fitting","xanes","asamacros","asaxseval","distdist","saxssim"]
 for _i in __all__:
   exec('from %s import *' % _i)
 _all1=dir()
@@ -6,6 +6,6 @@ _all1=dir()
 __all__=[_a for _a in _all1 if _a[0:2]!='__']
 #print __all__
 
-VERSION="0.5"
+VERSION="0.5.8"
 pass
 #comment
